import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_iam._jsii
import aws_cdk.aws_kms._jsii
import aws_cdk.aws_lambda._jsii
import aws_cdk.aws_s3._jsii
import aws_cdk.aws_ses._jsii
import aws_cdk.aws_sns._jsii
import aws_cdk.core._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-cdk/aws-ses-actions",
    "1.70.0",
    __name__[0:-6],
    "aws-ses-actions@1.70.0.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
